#!/bin/bash
# This script obtains event information by using FetchEvent, 
# and then generates eventtimes.txt for a3_download_event.m of ATaCR.
# FetchEvent can be download from https://seiscode.iris.washington.edu/projects/ws-fetch-scripts
# station information can be obtained from https://ds.iris.edu/mda
#
# Yuechu Wu
# 12131066@mail.sustech.edu.cn
# 2022-04-25



OStype="Mac OS"  # "Mac OS" for Mac OS X user, "Linux" for Linux user

#####station information######
network=7D
station=M08A
latitude=44.118698
longitude=-124.895302
elevation=-126.4

#####event parameter#####
begindate=2012-03-01
enddate=2012-03-15
maxradius=180  # maximum radius of the specified circular region
minradius=30 # minimum radius of the specified circular region, can be 0
minmag=5.5   # minimum magnitude
maxmag=10    # maximum magnitude

eventfile=$network.$station.eventlist.txt   # event list file name
timesfile=eventtimes_CItest.txt   # event time file name

if [ "$OStype" == "Mac OS" ]
then
    enddate=`date -v +1d -j -f "%Y-%m-%d" "${enddate}" "+%Y-%m-%d"`
elif [ "$OStype" == "Linux" ]
then
    enddate=`date -d "1 day ${enddate}" +%Y-%m-%d`
else
    echo "Incorrect system type!"
    exit 1
fi

./FetchEvent -s ${begindate}T00:00:00 -e ${enddate}T00:00:00 --radius $latitude:$longitude:$maxradius:$minradius --mag $minmag:$maxmag -o $eventfile

# cat eventlist.txt | awk '{split($2,a,"|" ); print a[2],$3}' | awk '{split($1,a,"/" ); print a[1],a[2],a[3],$2}' | awk '{split($4,a,":" ); print $1$2$3a[1]a[2]}'
echo making eventtimes of $network-$station from ${begindate}T00:00:00 to ${enddate}T00:00:00
cat $eventfile | awk -F"|" '{print $2}' | awk -F"/" '{print $1,$2,$3}' | awk -F":" '{print $1,$2,$3}' | awk -F"." '{print $1,$2}' | awk '{print $1$2$3$4$5$6}' > $timesfile


